@@ -17,7 +17,8 @@ class AGJsonToSQL:
     column_function: list = []
     window: list = []
     total: list = []
-    rollup: bool = False
+    rollup: list = []
+    cube: list = []
 
     where: list = []
     where_and: list = []
@@ -52,7 +53,8 @@ class AGJsonToSQL:
         self.column_function = []
         self.window = []
         self.total = []
-        self.rollup = False
+        self.rollup = []
+        self.cube = []
         self.offset = 0
         self.limit = 0
         self.page = 0
@@ -67,7 +69,7 @@ class AGJsonToSQL:
     #
     # SELECT
     #
-    def _get_column_name(self, column_name, alias_name):
+    def _get_column_name(self, column_name: str, alias_name: str) -> str:
         if "." in column_name:
             result = column_name
         else:
@@ -567,26 +569,49 @@ class AGJsonToSQL:
     #
     # GROUP BY
     #
+    def _get_group_by_column_list(self, select, alias):
+        column_list = ""
+        for f in select:
+            result = self.extract_datetime(f)
+            if result is not None:
+                column_name = result
+            else:
+                column_name = self._get_column_name(f, alias)
+
+            column_list += column_name + ", "
+
+        if len(column_list) > 0:
+            column_list = column_list[0:-2]
+
+        return column_list
+
+    def _get_group_by_format(self, c: Coder, select: list, format_list: list, alias: str, function: str) -> Coder:
+        format_column_list = self._get_group_by_column_list(format_list, alias)
+        ro_select: list = []
+        for s in select:
+            if s not in format_list:
+                ro_select.append(s)
+
+        if len(ro_select) > 0:
+            column_list = self._get_group_by_column_list(ro_select, alias)
+            c.a(0, "GROUP BY " + column_list + ", " + function + " (" + format_column_list + ")")
+        else:
+            c.a(0, "GROUP BY " + function + " (" + format_column_list + ")")
+
+        return c
+
     def _get_group_by(self, alias, select, total) -> Coder:
         c = Coder("sql")
 
         if len(total) > 0:
-            column_list = ""
-            for f in select:
-                result = self.extract_datetime(f)
-                if result is not None:
-                    column_name = result
-                else:
-                    column_name = self._get_column_name(f, alias)
+            column_list = self._get_group_by_column_list(select, alias)
 
-                column_list += column_name + ", "
-
-            if len(column_list) > 0:
-                column_list = column_list[0:-2]
-                if self.rollup:
-                    c.a(0, "GROUP BY ROLLUP (" + column_list + ")")
-                else:
-                    c.a(0, "GROUP BY " + column_list)
+            if len(self.rollup) > 0:
+                c = self._get_group_by_format(c, select, self.rollup, alias, "ROLLUP")
+            elif len(self.cube) > 0:
+                c = self._get_group_by_format(c, select, self.cube, alias, "CUBE")
+            else:
+                c.a(0, "GROUP BY " + column_list)
 
         return c
 
@@ -1112,6 +1137,9 @@ class AGJsonToSQL:
 
         if "rollup" in query:
             self.rollup = query["rollup"]
+        if "cube" in query:
+            self.cube = query["cube"]
+
         if "left_join" in query:
             self.left_join = query["left_join"]
         if "inner_join" in query:
