@@ -1,5 +1,5 @@
 import psycopg2
-from .query_json_to_sql import AGJsonToSQL
+from query_json_to_sql import AGJsonToSQL
 
 
 class AGQueryPostgres:
@@ -12,7 +12,13 @@ class AGQueryPostgres:
     query: dict = None
     rows: list = []
 
-    def __init__(self):
+    def __init__(self, conn=None, conn_string: str =''):
+        if conn is None:
+            self.conn_string = conn_string
+            self.conn = psycopg2.connect(self.conn_string)
+        else:
+            self.conn = conn
+
         self.SQL = ""
         self.inner_sql = ""
         self.query = {}
