@@ -1,7 +1,6 @@
 from AGCoder import Coder
 from uuid import UUID
-import datetime
-
+from datetime import datetime, date, time
 
 class AGQueryWhere:
     # Input
@@ -63,8 +62,12 @@ class AGQueryWhere:
                                 value = "'" + str(value) + "'"
                     elif type(value) is UUID:
                         value = "'" + str(value) + "'"
-                    elif type(value) is datetime.datetime:
-                        value = "'" + value.strftime('%Y-%m-%d %H:%M:%S') + "'"
+                    elif type(value) is datetime:
+                        value = "'" + str(value) + "'"
+                    elif type(value) is date:
+                        value = "'" + str(value) + "'"
+                    elif type(value) is time:
+                        value = "'" + str(value) + "'"
                     else:
                         value = str(value)
 
@@ -217,7 +220,7 @@ class AGQueryWhere:
         if "." in column_name:
             result = column_name
         else:
-            if alias_name:
+            if len(alias_name) > 0:
                 result = alias_name + "." + column_name
             else:
                 result = column_name
