@@ -1,5 +1,5 @@
 import psycopg2
-from settings import DB_CONNECTION
+from .settings import DB_CONNECTION
 from AGCoder import Coder
 from .query_postgres import AGQueryPostgres
 
